==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class FirmwareConfigFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<A>{
  public FirmwareConfigFluentImpl() {
  }
  public FirmwareConfigFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig instance) {
    this.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    this.withSriovEnabled(instance.getSriovEnabled()); 
    this.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean simultaneousMultithreadingEnabled;
  private java.lang.Boolean sriovEnabled;
  private java.lang.Boolean virtualizationEnabled;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled;
  }
  public A withSimultaneousMultithreadingEnabled(java.lang.Boolean simultaneousMultithreadingEnabled) {
    this.simultaneousMultithreadingEnabled=simultaneousMultithreadingEnabled; return (A) this;
  }
  public java.lang.Boolean hasSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled != null;
  }
  public java.lang.Boolean getSriovEnabled() {
    return this.sriovEnabled;
  }
  public A withSriovEnabled(java.lang.Boolean sriovEnabled) {
    this.sriovEnabled=sriovEnabled; return (A) this;
  }
  public java.lang.Boolean hasSriovEnabled() {
    return this.sriovEnabled != null;
  }
  public java.lang.Boolean getVirtualizationEnabled() {
    return this.virtualizationEnabled;
  }
  public A withVirtualizationEnabled(java.lang.Boolean virtualizationEnabled) {
    this.virtualizationEnabled=virtualizationEnabled; return (A) this;
  }
  public java.lang.Boolean hasVirtualizationEnabled() {
    return this.virtualizationEnabled != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FirmwareConfigFluentImpl that = (FirmwareConfigFluentImpl) o;
    if (simultaneousMultithreadingEnabled != null ? !simultaneousMultithreadingEnabled.equals(that.simultaneousMultithreadingEnabled) :that.simultaneousMultithreadingEnabled != null) return false;
    if (sriovEnabled != null ? !sriovEnabled.equals(that.sriovEnabled) :that.sriovEnabled != null) return false;
    if (virtualizationEnabled != null ? !virtualizationEnabled.equals(that.virtualizationEnabled) :that.virtualizationEnabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simultaneousMultithreadingEnabled,  sriovEnabled,  virtualizationEnabled,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/FirmwareConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class FirmwareConfigFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfigFluent<A>{
  public FirmwareConfigFluentImpl() {
  }
  public FirmwareConfigFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.FirmwareConfig instance) {
    this.withSimultaneousMultithreadingEnabled(instance.getSimultaneousMultithreadingEnabled()); 
    this.withSriovEnabled(instance.getSriovEnabled()); 
    this.withVirtualizationEnabled(instance.getVirtualizationEnabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean simultaneousMultithreadingEnabled;
  private java.lang.Boolean sriovEnabled;
  private java.lang.Boolean virtualizationEnabled;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled;
  }
  public A withSimultaneousMultithreadingEnabled(java.lang.Boolean simultaneousMultithreadingEnabled) {
    this.simultaneousMultithreadingEnabled=simultaneousMultithreadingEnabled; return (A) this;
  }
  public java.lang.Boolean hasSimultaneousMultithreadingEnabled() {
    return this.simultaneousMultithreadingEnabled != null;
  }
  public java.lang.Boolean getSriovEnabled() {
    return this.sriovEnabled;
  }
  public A withSriovEnabled(java.lang.Boolean sriovEnabled) {
    this.sriovEnabled=sriovEnabled; return (A) this;
  }
  public java.lang.Boolean hasSriovEnabled() {
    return this.sriovEnabled != null;
  }
  public java.lang.Boolean getVirtualizationEnabled() {
    return this.virtualizationEnabled;
  }
  public A withVirtualizationEnabled(java.lang.Boolean virtualizationEnabled) {
    this.virtualizationEnabled=virtualizationEnabled; return (A) this;
  }
  public java.lang.Boolean hasVirtualizationEnabled() {
    return this.virtualizationEnabled != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FirmwareConfigFluentImpl that = (FirmwareConfigFluentImpl) o;
    if (simultaneousMultithreadingEnabled != null ? !simultaneousMultithreadingEnabled.equals(that.simultaneousMultithreadingEnabled) :that.simultaneousMultithreadingEnabled != null) return false;
    if (sriovEnabled != null ? !sriovEnabled.equals(that.sriovEnabled) :that.sriovEnabled != null) return false;
    if (virtualizationEnabled != null ? !virtualizationEnabled.equals(that.virtualizationEnabled) :that.virtualizationEnabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(simultaneousMultithreadingEnabled,  sriovEnabled,  virtualizationEnabled,  additionalProperties,  super.hashCode());
  }
  
}
